This is a historic tribunal. The functions of this tribunal have been transferred to the General Regulatory Chamber of the First-tier Tribunal. The GRC began transferring records to Find Case Law in 2022. To view an archived version of the decisions of this tribunal from 2009-2011 visit the [UK Government Web Archive](https://webarchive.nationalarchives.gov.uk/ukgwa/20200626120017/http://claimsmanagement.decisions.tribunals.gov.uk/).
